@@ -44,7 +44,7 @@ class FastaRecord(object):
         """
         f = fasta_obj.fasta_name
         if klass.is_current(f):
-            fh = open(f + klass.idx)
+            fh = open(f + klass.idx, 'rb')
             idx = cPickle.load(fh)
             fh.close()
             if flatten_inplace or ext_is_flat(f + klass.ext): flat = klass.modify_flat(f)
@@ -177,13 +177,13 @@ class FastaRecord(object):
 
 
 class NpyFastaRecord(FastaRecord):
-    __slots__ = ('start', 'stop', 'mm', 'tostring')
+    __slots__ = ('start', 'stop', 'mm', 'as_string')
 
-    def __init__(self, mm, start, stop, tostring=True):
+    def __init__(self, mm, start, stop, as_string=True):
         self.mm = mm
         self.start = start
         self.stop = stop
-        self.tostring = tostring
+        self.as_string = as_string
 
     def __repr__(self):
         return "%s(%i..%i)" % (self.__class__.__name__,
@@ -208,7 +208,7 @@ class NpyFastaRecord(FastaRecord):
 
     def __getitem__(self, islice):
         d = self.getdata(islice)
-        return d.tostring() if self.tostring else d
+        return d.tostring() if self.as_string else d
 
     @property
     def __array_interface__(self):
@@ -221,6 +221,10 @@ class NpyFastaRecord(FastaRecord):
 
 
 class MemoryRecord(FastaRecord):
+    """
+    dont write anything to disk, just read the whole thing
+    into memory
+    """
     @classmethod
     def prepare(klass, fasta_obj, seqinfo_generator, flatten_inplace=False):
         f = fasta_obj.fasta_name
@@ -228,7 +232,7 @@ class MemoryRecord(FastaRecord):
         idx = {}
         for seqid, seq in seqinfo_generator:
             seqs[seqid] = (seq, None)
-            
+
         return seqs, seqs
 
     def __init__(self, _, seq, _none):
